@@ -212,12 +212,12 @@ globus_result_t globus_gsi_cred_read_proxy_bio(
 
 globus_result_t globus_gsi_cred_read_key(
     globus_gsi_cred_handle_t            handle,
-    char *                              key_filename,
+    const char *                        key_filename,
     int                                 (*pw_cb)());
 
 globus_result_t globus_gsi_cred_read_cert(
     globus_gsi_cred_handle_t            handle,
-    char *                              cert_filename);
+    const char *                        cert_filename);
 
 globus_result_t globus_gsi_cred_read_cert_bio(
     globus_gsi_cred_handle_t            handle,
@@ -232,7 +232,7 @@ globus_result_t globus_gsi_cred_read_cert_buffer(
 
 globus_result_t globus_gsi_cred_read_pkcs12(
     globus_gsi_cred_handle_t            handle,
-    char *                              pkcs12_filename);
+    const char *                        pkcs12_filename);
 
 globus_result_t globus_gsi_cred_write(
     globus_gsi_cred_handle_t            handle,
@@ -240,7 +240,7 @@ globus_result_t globus_gsi_cred_write(
 
 globus_result_t globus_gsi_cred_write_proxy(
     globus_gsi_cred_handle_t            handle,
-    char *                              proxy_filename);
+    const char *                        proxy_filename);
 
 globus_result_t
 globus_gsi_cred_verify_cert_chain(
